@@ -1,4 +1,5 @@
 from django.core.management.commands.test import Command as TestCommand
+
 import os
 from optparse import make_option
 import sys
@@ -11,6 +12,11 @@ class Command(TestCommand):
                     ),)
 
     def handle(self, *test_labels, **options):
+        try:
+            from south.management.commands import patch_for_test_db_setup
+            patch_for_test_db_setup()
+        except ImportError:
+            pass
         from django.conf import settings
         from django.test.utils import get_runner
 
