@@ -8,17 +8,17 @@ import settings
 class DiscoverTeamcityRunner(DiscoverRunner):
     def __init__(self, *args, **kwargs):
 
-        if kwargs['with_selenium']:
+        if kwargs.get('with_selenium'):
             settings.WITH_SELENIUM = True
         super(DiscoverTeamcityRunner, self).__init__(*args, **kwargs)
 
     def run_suite(self, suite, **kwargs):
         if is_running_under_teamcity():
-            runner = TeamcityTestRunner
+            runner = TeamcityTestRunner()
         else:
-            runner = unittest.TextTestRunner
-            return runner(verbosity=self.verbosity,
-                          failfast=self.failfast,
-                          ).run(suite)
+            runner = unittest.TextTestRunner(verbosity=self.verbosity,
+                                             failfast=self.failfast,
+                                             )
+        return runner.run(suite)
     
 
